[jboss-cvs] JBossAS SVN: r63463 - in projects/aop/trunk/aop: docs/examples/annotated-parameters and 10 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Mon Jun 11 22:30:53 EDT 2007


Author: flavia.rainone at jboss.com
Date: 2007-06-11 22:30:52 -0400 (Mon, 11 Jun 2007)
New Revision: 63463

Modified:
   projects/aop/trunk/aop/docs/examples/after-throwing/Aspect.java
   projects/aop/trunk/aop/docs/examples/after-throwing/after-throwing.html
   projects/aop/trunk/aop/docs/examples/after-throwing/jboss-aop.xml
   projects/aop/trunk/aop/docs/examples/annotated-parameters/Aspect.java
   projects/aop/trunk/aop/docs/examples/annotated-parameters/annotated-parameters.html
   projects/aop/trunk/aop/docs/examples/beforeafter/MutexAspect.java
   projects/aop/trunk/aop/docs/examples/beforeafter/beforeafter.html
   projects/aop/trunk/aop/docs/examples/finally/MutexAspect.java
   projects/aop/trunk/aop/docs/examples/finally/finally.html
   projects/aop/trunk/aop/docs/examples/overloaded-advices/JoinPointAspect.java
   projects/aop/trunk/aop/docs/examples/overloaded-advices/MixedParametersAspect.java
   projects/aop/trunk/aop/docs/examples/overloaded-advices/overloaded-advices.html
   projects/aop/trunk/aop/docs/examples/return-types/Aspect.java
   projects/aop/trunk/aop/docs/misc/joinpoint.html
   projects/aop/trunk/aop/docs/reference/reference/en/modules/advices.xml
   projects/aop/trunk/aop/docs/reference/reference/en/modules/pointcuts.xml
   projects/aop/trunk/aop/src/main/org/jboss/aop/advice/AdviceMethodProperties.java
   projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java
   projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointTestCase.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedBeforeAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/container/ContainerTestCase.java
Log:
[JBAOP-373] Update on documentations, and more updates on classes.

Modified: projects/aop/trunk/aop/docs/examples/after-throwing/Aspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/after-throwing/Aspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/after-throwing/Aspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -24,7 +24,7 @@
 import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.advice.annotation.Thrown;
 
-import org.jboss.aop.joinpoint.IMethodInfo;
+import org.jboss.aop.joinpoint.MethodExecution;
 
 public class Aspect
 {
@@ -33,9 +33,9 @@
       System.out.println(">>> afterThrowing: " + thrown);
    }
    
-   public void afterThrowingInfo(@JoinPoint IMethodInfo methodInfo, @Thrown Throwable thrown)
+   public void afterThrowingJoinPoint(@JoinPoint MethodExecution methodExecution, @Thrown Throwable thrown)
    {
-      System.out.println(">>> afterThrowingInfo: " + thrown);
+      System.out.println(">>> afterThrowingJoinPoint: " + thrown);
    }
    
    public void afterThrowingArg(@Thrown Throwable thrown, @Arg String argument)
@@ -43,8 +43,8 @@
       System.out.println(">>> afterThrowingArg: " + thrown);
    }
    
-   public void afterThrowingInfoArg(@Thrown Throwable thrown, @JoinPoint IMethodInfo methodInfo, @Arg String argument)
+   public void afterThrowingJoinPointArg(@Thrown Throwable thrown, @JoinPoint MethodExecution methodExecution, @Arg String argument)
    {
-      System.out.println(">>> afterThrowingInfoArg: " + thrown);
+      System.out.println(">>> afterThrowingJoinPointArg: " + thrown);
    }
 }
\ No newline at end of file

Modified: projects/aop/trunk/aop/docs/examples/after-throwing/after-throwing.html
===================================================================
--- projects/aop/trunk/aop/docs/examples/after-throwing/after-throwing.html	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/after-throwing/after-throwing.html	2007-06-12 02:30:52 UTC (rev 63463)
@@ -63,7 +63,7 @@
 The following advice signature is valid to intercept a method execution throwing an
 exception:
 <pre>
-public void afterThrowingInfo(@JoinPoint IMethodInfo methodInfo, @Thrown Throwable thrown)
+public void afterThrowingJoinPoint(@JoinPoint MethodExecution methodExecution, @Thrown Throwable thrown)
 </pre>
 </p><p>
 Notice that you can declare the annotated parameters in any order you wish.
@@ -73,7 +73,7 @@
 </p><p>
 <pre>
 public void afterThrowingArg(@Thrown Throwable thrown, @Arg String argument)
-public void afterThrowingInfoArg(@Thrown Throwable thrown, @JoinPoint IMethodInfo methodInfo, @Arg String argument)
+public void afterThrowingJoinPointArg(@Thrown Throwable thrown, @JoinPoint MethodExecution methodExecution, @Arg String argument)
 </pre>
 </p><p>
 </p><p>
@@ -93,9 +93,9 @@
      [java] ====================================
      [java] RUNNING POJO-&gt;throwsExceptionMethod("argument")
      [java] &gt;&gt;&gt; afterThrowing: java.lang.Exception: POJO Exception
-     [java] &gt;&gt;&gt; afterThrowingInfo: java.lang.Exception: POJO Exception
+     [java] &gt;&gt;&gt; afterThrowingJoinPoint: java.lang.Exception: POJO Exception
      [java] &gt;&gt;&gt; afterThrowingArg: java.lang.Exception: POJO Exception
-     [java] &gt;&gt;&gt; afterThrowingInfoArg: java.lang.Exception: POJO Exception
+     [java] &gt;&gt;&gt; afterThrowingJoinPointArg: java.lang.Exception: POJO Exception
      [java] Caching Exception java.lang.Exception: POJO Exception
 
      [java] Calling POJO-&gt;throwNothingMethod()

Modified: projects/aop/trunk/aop/docs/examples/after-throwing/jboss-aop.xml
===================================================================
--- projects/aop/trunk/aop/docs/examples/after-throwing/jboss-aop.xml	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/after-throwing/jboss-aop.xml	2007-06-12 02:30:52 UTC (rev 63463)
@@ -5,9 +5,9 @@
 
    <bind pointcut="execution(* POJO->*(..))">
       <throwing name="afterThrowing" aspect="Aspect"/>
-      <throwing name="afterThrowingInfo" aspect="Aspect"/>
+      <throwing name="afterThrowingJoinPoint" aspect="Aspect"/>
       <throwing name="afterThrowingArg" aspect="Aspect"/>
-      <throwing name="afterThrowingInfoArg" aspect="Aspect"/>
+      <throwing name="afterThrowingJoinPointArg" aspect="Aspect"/>
    </bind>
    
 </aop>
\ No newline at end of file

Modified: projects/aop/trunk/aop/docs/examples/annotated-parameters/Aspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/annotated-parameters/Aspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/annotated-parameters/Aspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -20,9 +20,6 @@
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
 
-import org.jboss.aop.ConstructorInfo;
-import org.jboss.aop.FieldInfo;
-import org.jboss.aop.JoinPointInfo;
 
 import org.jboss.aop.advice.annotation.Arg;
 import org.jboss.aop.advice.annotation.Args;
@@ -32,15 +29,18 @@
 import org.jboss.aop.advice.annotation.Target;
 
 import org.jboss.aop.joinpoint.CallerInvocation;
+import org.jboss.aop.joinpoint.ConstructorExecution;
 import org.jboss.aop.joinpoint.CurrentInvocation;
+import org.jboss.aop.joinpoint.JoinPointBean;
 
+
 public class Aspect
 {
    // @JoinPoint
    
-   public void beforeJoinPoint(@JoinPoint JoinPointInfo joinPointInfo)
+   public void beforeJoinPoint(@JoinPoint JoinPointBean joinPoint)
    {
-      System.out.println(">>> beforeJoinPoint: FieldInfo " + joinPointInfo);
+      System.out.println(">>> beforeJoinPoint: JoinPointBean " + joinPoint);
    }
    
    public Object aroundJoinPoint(@JoinPoint CallerInvocation invocation) throws Throwable
@@ -49,9 +49,9 @@
       return invocation.invokeNext();
    }
    
-   public void afterJoinPoint(@JoinPoint ConstructorInfo joinPointInfo)
+   public void afterJoinPoint(@JoinPoint ConstructorExecution joinPoint)
    {
-      System.out.println(">>> afterJoinPoint: ConstructorInfo " + joinPointInfo);
+      System.out.println(">>> afterJoinPoint: ConstructorExecution " + joinPoint);
    }
    
    // @Target

Modified: projects/aop/trunk/aop/docs/examples/annotated-parameters/annotated-parameters.html
===================================================================
--- projects/aop/trunk/aop/docs/examples/annotated-parameters/annotated-parameters.html	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/annotated-parameters/annotated-parameters.html	2007-06-12 02:30:52 UTC (rev 63463)
@@ -88,19 +88,19 @@
 is an around advice, the type of this object belongs to the
 <a href="../../misc/invocation.html">Invocation class hierarchy</a>. On all other
 advices, joinpoints are represented by types of the
-<a href="../../misc/joinpoint.html">JoinPoint interface hierarchy</a>, as follows:
+<a href="../../misc/joinpoint.html">JoinPointBean interface hierarchy</a>, as follows:
 </p><p>
 <pre>
-public void beforeJoinPoint(@JoinPoint JoinPointInfo joinPointInfo)
+public void beforeJoinPoint(@JoinPoint JoinPointBean joinPoint)
 
 public Object aroundJoinPoint(@JoinPoint CallerInvocation invocation) throws Throwable
 
-public void afterJoinPoint(@JoinPoint ConstructorInfo joinPointInfo)
+public void afterJoinPoint(@JoinPoint ConstructorExecution joinPoint)
 </pre>
 </p><p>
 Notice how <tt>beforeJoinPoint</tt> advice receives a parameter of the supertype
-<tt>JoinPointInfo</tt> while, in <tt>afterJoinPoint</tt>, the parameter is of the more
-specific type <tt>ConstructorInfo</tt>, valid only on constructor execution
+<tt>JoinPointBean</tt> while, in <tt>afterJoinPoint</tt>, the parameter is of the more
+specific type <tt>ConstructorExecution</tt>, valid only on constructor execution
 joinpoints.
 To see these and all other advice examples, open up the <tt>Aspect.java</tt> file.
 </p><p>
@@ -278,11 +278,11 @@
      [java] &gt;&gt;&gt; beforeConstructorArg: Object "Driver"
      [java] &gt;&gt;&gt; aroundConstructorArg: String "Driver"
      [java] RUNNING new POJO("Driver")
-     [java] &gt;&gt;&gt; afterJoinPoint: ConstructorInfo Constructor[constructor=public POJO(java.lang.String)]
+     [java] &gt;&gt;&gt; afterJoinPoint: ConstructorExecution Constructor[constructor=public POJO(java.lang.String)]
 
      [java] Setting POJO-&gt;field with "text" value
      [java] =======================================
-     [java] &gt;&gt;&gt; beforeJoinPoint: FieldInfo Field Write[field=public java.lang.Object POJO.field]
+     [java] &gt;&gt;&gt; beforeJoinPoint: JoinPointBean Field Write[field=public java.lang.Object POJO.field]
      [java] &gt;&gt;&gt; aroundTarget: POJO POJO at 19209ea
      [java] &gt;&gt;&gt; aroundArgs: arguments [text]
 

Modified: projects/aop/trunk/aop/docs/examples/beforeafter/MutexAspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/beforeafter/MutexAspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/beforeafter/MutexAspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -22,14 +22,14 @@
 
 import org.jboss.aop.advice.annotation.JoinPoint;
 
-import org.jboss.aop.JoinPointInfo; 
+import org.jboss.aop.joinpoint.JoinPointBean; 
 
 public class MutexAspect
 {
    private Object lock = new Object();
    private boolean locked = false;   
    
-   public void beforeAdvice(@JoinPoint JoinPointInfo joinPoint)
+   public void beforeAdvice(@JoinPoint JoinPointBean joinPoint)
    {
       synchronized(lock)
       {
@@ -50,7 +50,7 @@
       }
    }
    
-   public void afterAdvice(@JoinPoint JoinPointInfo joinPoint)
+   public void afterAdvice(@JoinPoint JoinPointBean joinPoint)
    {
       synchronized(lock)
       {

Modified: projects/aop/trunk/aop/docs/examples/beforeafter/beforeafter.html
===================================================================
--- projects/aop/trunk/aop/docs/examples/beforeafter/beforeafter.html	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/beforeafter/beforeafter.html	2007-06-12 02:30:52 UTC (rev 63463)
@@ -32,7 +32,7 @@
 is not necessary, because these advices do not wrap a joinpoint.
 </p><p>
 Instead of <a href="../../misc/invocation.html"><tt>Invocation</tt></a> instances, before/after advices receive instances
-of <a href="../../misc/joinpoint.html"><tt>org.jboss.aop.IJoinpointInfo</tt> and subinterfaces</a>
+of <a href="../../misc/joinpoint.html"><tt>org.jboss.aop.joinpoint.JoinpointBean</tt> and subinterfaces</a>
 as parameters.
 </p><p>
 Furthermore, one can notice the presence of the parameter annotation <tt>@org.jboss.aop.advice.annotation.JoinPoint</tt>. This is necessary because
@@ -331,8 +331,6 @@
 
      [java] TRANSACTIONS
      [java] ============
-     [java] Using context classloader sun.misc.Launcher$AppClassLoader at 133056f to load aspect mypackage.MutexAspect
-     [java] Using context classloader sun.misc.Launcher$AppClassLoader at 133056f to load aspect mypackage.MutexAspect
      [java] &gt;&gt;&gt; Retrieved concurrency lock
      [java] Depositing US$ 50.00 to account A
      [java] &lt;&lt;&lt; Releasing concurrency lock

Modified: projects/aop/trunk/aop/docs/examples/finally/MutexAspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/finally/MutexAspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/finally/MutexAspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -23,14 +23,14 @@
 import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.advice.annotation.Thrown;
 
-import org.jboss.aop.JoinPointInfo; 
+import org.jboss.aop.joinpoint.JoinPointBean; 
 
 public class MutexAspect
 {
    private Object lock = new Object();
    private boolean locked = false;   
    
-   public void beforeAdvice(@JoinPoint JoinPointInfo joinPoint)
+   public void beforeAdvice(@JoinPoint JoinPointBean joinPoint)
    {
       synchronized(lock)
       {
@@ -51,7 +51,7 @@
       }
    }
    
-   public void finallyAdvice(@JoinPoint JoinPointInfo joinPoint)
+   public void finallyAdvice(@JoinPoint JoinPointBean joinPoint)
    {
       synchronized(lock)
       {

Modified: projects/aop/trunk/aop/docs/examples/finally/finally.html
===================================================================
--- projects/aop/trunk/aop/docs/examples/finally/finally.html	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/finally/finally.html	2007-06-12 02:30:52 UTC (rev 63463)
@@ -146,7 +146,7 @@
    private Object lock = new Object();
    private boolean locked = false;
 
-   public void beforeAdvice(@JoinPoint JoinPointInfo joinPoint)
+   public void beforeAdvice(@JoinPoint JoinPointBean joinPoint)
    {
       synchronized(lock)
       {
@@ -167,7 +167,7 @@
       }
    }
 
-   public void finallyAdvice(@JoinPoint JoinPointInfo joinPoint)
+   public void finallyAdvice(@JoinPoint JoinPointBean joinPoint)
    {
       synchronized(lock)
       {
@@ -349,6 +349,10 @@
 </p><p>
 As before, you can add accounts and transactions to this example application by editing the
 <tt>input.txt</tt> file.
+</p><p>
+Note that you can retrieve different values by running this example, since the order
+of operations varies (they are concurrent after all) and an operation with negative
+outcome will be invalidated.
 </p>
 </body>
 </html>

Modified: projects/aop/trunk/aop/docs/examples/overloaded-advices/JoinPointAspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/overloaded-advices/JoinPointAspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/overloaded-advices/JoinPointAspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -23,11 +23,11 @@
 import org.jboss.aop.advice.annotation.JoinPoint;
 
 import org.jboss.aop.joinpoint.ConstructorInvocation;
+import org.jboss.aop.joinpoint.ConstructorExecution;
+import org.jboss.aop.joinpoint.FieldAccess;
 import org.jboss.aop.joinpoint.FieldReadInvocation;
 import org.jboss.aop.joinpoint.FieldWriteInvocation;
-import org.jboss.aop.joinpoint.IConstructorInfo;
-import org.jboss.aop.joinpoint.IFieldInfo;
-import org.jboss.aop.joinpoint.IMethodInfo;
+import org.jboss.aop.joinpoint.MethodExecution;
 import org.jboss.aop.joinpoint.MethodInvocation;
 
 public class JoinPointAspect
@@ -60,19 +60,19 @@
       return invocation.invokeNext();
    }
    
-   public void otherTypeOfAdvice(@JoinPoint IConstructorInfo joinPoint)
+   public void otherTypeOfAdvice(@JoinPoint ConstructorExecution joinPoint)
    {
       System.out.println(">>> otherTypeOfAdvice on constructor of class: " +
             joinPoint.getConstructor().getDeclaringClass().getName());
    }
    
-   public void otherTypeOfAdvice(@JoinPoint IMethodInfo joinPoint)
+   public void otherTypeOfAdvice(@JoinPoint MethodExecution joinPoint)
    {
       System.out.println(">>> otherTypeOfAdvice on method execution: " +
             joinPoint.getAdvisedMethod().getName());
    }
       
-   public void otherTypeOfAdvice(@JoinPoint IFieldInfo joinPoint)
+   public void otherTypeOfAdvice(@JoinPoint FieldAccess joinPoint)
    {
       System.out.println(">>> otherTypeOfAdvice on field" +
          (joinPoint.isRead()? "read: ": "write: ") +

Modified: projects/aop/trunk/aop/docs/examples/overloaded-advices/MixedParametersAspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/overloaded-advices/MixedParametersAspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/overloaded-advices/MixedParametersAspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -25,9 +25,9 @@
 import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.advice.annotation.Target;
 
-import org.jboss.aop.joinpoint.IConstructorInfo;
-import org.jboss.aop.joinpoint.IJoinPointInfo;
-import org.jboss.aop.joinpoint.ICallerMethodInfo;
+import org.jboss.aop.joinpoint.ConstructorExecution;
+import org.jboss.aop.joinpoint.JoinPointBean;
+import org.jboss.aop.joinpoint.MethodCall;
 
 public class MixedParametersAspect
 {
@@ -37,9 +37,9 @@
       return 0;
    }
 
-   public void overloadedAdvice(@JoinPoint IConstructorInfo joinPoint)
+   public void overloadedAdvice(@JoinPoint ConstructorExecution joinPoint)
    {
-      System.out.println(">>> overloadedAdvice: (JoinPoint IConstructorInfo)");
+      System.out.println(">>> overloadedAdvice: (JoinPoint ConstructorExecution)");
    }
 
    public void overloadedAdvice(@Target Object target)
@@ -47,13 +47,13 @@
       System.out.println(">>> overloadedAdvice: (Target Object)");
    }
 
-   public void overloadedAdvice(@JoinPoint ICallerMethodInfo joinPoint, @Caller Driver driver)
+   public void overloadedAdvice(@JoinPoint MethodCall joinPoint, @Caller Driver driver)
    {
-      System.out.println(">>> overloadedAdvice: (JoinPoint ICallerMethodInfo, Caller Driver)");
+      System.out.println(">>> overloadedAdvice: (JoinPoint MethodCall, Caller Driver)");
    }
 
-   public void overloadedAdvice(@JoinPoint IJoinPointInfo joinPoint, @Arg String arg)
+   public void overloadedAdvice(@JoinPoint JoinPointBean joinPoint, @Arg String arg)
    {
-      System.out.println(">>> overloadedAdvice: JoinPoint IJoinPoint, Arg String");
+      System.out.println(">>> overloadedAdvice: JoinPoint JoinPointBean, Arg String");
    }
 }
\ No newline at end of file

Modified: projects/aop/trunk/aop/docs/examples/overloaded-advices/overloaded-advices.html
===================================================================
--- projects/aop/trunk/aop/docs/examples/overloaded-advices/overloaded-advices.html	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/overloaded-advices/overloaded-advices.html	2007-06-12 02:30:52 UTC (rev 63463)
@@ -96,19 +96,19 @@
 </p><p>
 This example could also be applied to another type of advice with minor changes:
 <pre>
-public void otherTypeOfAdvice(@JoinPoint IConstructorInfo joinPoint)
+public void otherTypeOfAdvice(@JoinPoint ConstructorExecution joinPoint)
 {
    System.out.println("&gt;&gt;&gt; otherTypeOfAdvice on constructor of class: " +
          joinPoint.getConstructor().getDeclaringClass().getName());
 }
 
-public void otherTypeOfAdvice(@JoinPoint IMethodInfo joinPoint)
+public void otherTypeOfAdvice(@JoinPoint MethodExecution joinPoint)
 {
    System.out.println("&gt;&gt;&gt; otherTypeOfAdvice on method execution: " +
          joinPoint.getAdvisedMethod().getName());
 }
 
-public void otherTypeOfAdvice(@JoinPoint IFieldInfo joinPoint)
+public void otherTypeOfAdvice(@JoinPoint FieldAccess joinPoint)
 {
    System.out.println("&gt;&gt;&gt; otherTypeOfAdvice on field" +
       (joinPoint.isRead()? "read: ": "write: ") +
@@ -122,7 +122,7 @@
 &lt;/bind&gt;
 </pre>
 </p><p>
-Notice that <tt>IFieldInfo</tt> is used for both field read and write joinpoints. The
+Notice that <tt>FieldAccess</tt> is used for both field read and write joinpoints. The
 <tt>otherTypeOfAdvice</tt> advice is applied as a before advice in the example. However,
 it could have been applied as an after advice, or a finally advice. And it could
 also have been applied as an after-throwing advice if we added a <tt>@Thrown</tt>
@@ -144,9 +144,9 @@
    return 0;
 }
 
-public void overloadedAdvice(@JoinPoint IConstructorInfo joinPoint)
+public void overloadedAdvice(@JoinPoint ConstructorExecution joinPoint)
 {
-   System.out.println("&gt;&gt;&gt; overloadedAdvice: (JoinPoint IConstructorInfo)");
+   System.out.println("&gt;&gt;&gt; overloadedAdvice: (JoinPoint ConstructorExecution)");
 }
 
 public void overloadedAdvice(@Target Object target)
@@ -154,14 +154,14 @@
    System.out.println("&gt;&gt;&gt; overloadedAdvice: (Target Object)");
 }
 
-public void overloadedAdvice(@JoinPoint ICallerMethodInfo joinPoint, @Caller Driver driver)
+public void overloadedAdvice(@JoinPoint MethodCall joinPoint, @Caller Driver driver)
 {
-   System.out.println("&gt;&gt;&gt; overloadedAdvice: (JoinPoint ICallerMethodInfo, Caller Driver)");
+   System.out.println("&gt;&gt;&gt; overloadedAdvice: (JoinPoint MethodCall, Caller Driver)");
 }
 
-public void overloadedAdvice(@JoinPoint IJoinPointInfo joinPoint, @Arg String arg)
+public void overloadedAdvice(@JoinPoint JoinPointBean joinPoint, @Arg String arg)
 {
-   System.out.println("&gt;&gt;&gt; overloadedAdvice: JoinPoint IJoinPoint, Arg String");
+   System.out.println("&gt;&gt;&gt; overloadedAdvice: JoinPoint JoinPointBean, Arg String");
 }
 </pre>
 </p><p>
@@ -191,7 +191,7 @@
      [java] ========================
      [java] &gt;&gt;&gt; otherTypeOfAdvice on constructor of class: POJO
      [java] &gt;&gt;&gt; aroundAdvice on constructor of class: POJO
-     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint IConstructorInfo)
+     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint ConstructorExecution)
 
      [java] Setting POJO-&gt;intField with 1751 value
      [java] ======================================
@@ -209,7 +209,7 @@
      [java] ===========================================
      [java] &gt;&gt;&gt; otherTypeOfAdvice on fieldwrite: stringField
      [java] &gt;&gt;&gt; aroundAdvice on field write: stringField
-     [java] &gt;&gt;&gt; overloadedAdvice: JoinPoint IJoinPoint, Arg String
+     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint JoinPointBean, Arg String)
 
      [java] Reading POJO-&gt;stringField value
      [java] ===============================
@@ -223,15 +223,15 @@
      [java] &gt;&gt;&gt; aroundAdvice on method execution: voidMethod
      [java] RUNNING POJO-&gt;voidMethod()
      [java] &gt;&gt;&gt; overloadedAdvice: int(Target POJO)
-     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint ICallerMethodInfo, Caller Driver)
+     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint MethodCall, Caller Driver)
 
      [java] Calling POJO-&gt;methodWithStringArg()
      [java] ===================================
      [java] &gt;&gt;&gt; otherTypeOfAdvice on method execution: methodWithStringArg
      [java] &gt;&gt;&gt; aroundAdvice on method execution: methodWithStringArg
      [java] RUNNING POJO-&gt;methodWithStringArg("stringArg")
-     [java] &gt;&gt;&gt; overloadedAdvice: JoinPoint IJoinPoint, Arg String
-     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint ICallerMethodInfo, Caller Driver)
+     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint JoinPointBean, Arg String)
+     [java] &gt;&gt;&gt; overloadedAdvice: (JoinPoint MethodCall, Caller Driver)
 </pre>
 </p><p>
 </p>

Modified: projects/aop/trunk/aop/docs/examples/return-types/Aspect.java
===================================================================
--- projects/aop/trunk/aop/docs/examples/return-types/Aspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/examples/return-types/Aspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -24,8 +24,6 @@
 import java.util.Collections;
 import java.util.List;
 
-import org.jboss.aop.MethodInfo;
-
 import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.advice.annotation.Return;
 

Modified: projects/aop/trunk/aop/docs/misc/joinpoint.html
===================================================================
--- projects/aop/trunk/aop/docs/misc/joinpoint.html	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/misc/joinpoint.html	2007-06-12 02:30:52 UTC (rev 63463)
@@ -4,20 +4,20 @@
 <h2>JoinPoint Hierarchy</h2>
 
 </p><p>
-<tt>org.jboss.aop.joinpoint.JoinpointInfo</tt> is the base interface for a bunch of different subtypes.
+<tt>org.jboss.aop.joinpoint.JoinpointBean</tt> is the base interface for a bunch of different subtypes.
 Depending on the type of joinpoint being intercepted (only by before, after and after
-throwing advices), a different JoinpointInfo subinterface is provided. All of the
+throwing advices), a different JoinpointBean subinterface is provided. All of the
 subinterfaces are in the <tt>org.jboss.aop.joinpoint</tt> package.
 </p><p>
 <table border="1">
-<tr><td>execution(method)</td><td>org.jboss.aop.joinpoint.IMethodInfo</td></tr>
-<tr><td>get(field)</td><td>org.jboss.aop.joinpoint.IFieldInfo</td></tr>
-<tr><td>set(field)</td><td>org.jboss.aop.joinpoint.IFieldInfo</td></tr>
-<tr><td>execution(constructor)</td><td>org.jboss.aop.joinpoint.IConstructorInfo</td></tr>
-<tr><td>call(method) AND withincode(method)</td><td>org.jboss.aop.joinpoint.IMethodByMethodInfo</td></tr>
-<tr><td>call(method) AND withincode(constructor)</td><td>org.jboss.aop.joinpoint.IMethodByConInfo</td></tr>
-<tr><td>call(constructor) AND withincode(constructor)</td><td>org.jboss.aop.joinpoint.IConByConInfo</td></tr>
-<tr><td>call(constructor) AND withincode(method)</td><td>org.jboss.aop.joinpoint.IConByMethodInfo</td></tr>
+<tr><td>execution(method)</td><td>org.jboss.aop.joinpoint.MethodExecution</td></tr>
+<tr><td>get(field)</td><td>org.jboss.aop.joinpoint.FieldAccess</td></tr>
+<tr><td>set(field)</td><td>org.jboss.aop.joinpoint.FieldAccess</td></tr>
+<tr><td>execution(constructor)</td><td>org.jboss.aop.joinpoint.ConstructorExecution</td></tr>
+<tr><td>call(method) AND withincode(method)</td><td>org.jboss.aop.joinpoint.MethodCallByMethod</td></tr>
+<tr><td>call(method) AND withincode(constructor)</td><td>org.jboss.aop.joinpoint.MethodCallByConstructor</td></tr>
+<tr><td>call(constructor) AND withincode(constructor)</td><td>org.jboss.aop.joinpoint.ConstructorCallByConstructor</td></tr>
+<tr><td>call(constructor) AND withincode(method)</td><td>org.jboss.aop.joinpoint.ConstructorCallByMethod</td></tr>
 </table>
 </p><p>
 </p>

Modified: projects/aop/trunk/aop/docs/reference/reference/en/modules/advices.xml
===================================================================
--- projects/aop/trunk/aop/docs/reference/reference/en/modules/advices.xml	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/reference/reference/en/modules/advices.xml	2007-06-12 02:30:52 UTC (rev 63463)
@@ -110,9 +110,9 @@
          avoiding the creation of the <literal>Invocation</literal> objects per joinpoint execution.
       </para>
       <para>
-         Instead of <literal>Invocation</literal> objects, JBoss AOP provides <link linkend="pointcuts-typetable">JoinPointInfo beans</link>
+         Instead of <literal>Invocation</literal> objects, JBoss AOP provides <link linkend="pointcuts-typetable">JoinPointBean beans</link>
          for these advices. As described in <xref linkend="pointcuts-beans"/>, these beans contain all information regarding a joinpoint,
-         like an <literal>Invocation</literal> would do. However, since <literal>IJoinPointInfo</literal> objects are not used on around
+         like an <literal>Invocation</literal> would do. However, since <literal>JoinPointBean</literal> objects are not used on around
          advice types, they do not provide proceeding methods, like <literal>invokeNext()</literal>. They also do not allow you to
          attach metadata for a particular invocation.
       </para>
@@ -212,7 +212,7 @@
          <literal>MethodInvocation</literal>, or an <literal>Invocation</literal> (the complete list of joinpoint beans
          and their relationship with joinpoint types was shown in <xref linkend="pointcuts-typetable">in a previously seen table</xref>).
          As already explained, around advices use <literal>Invocation</literal> instances, while the other advices use
-         <literal>IJoinPointInfo</literal> objects.
+         <literal>JoinPointBean</literal> objects.
       </para>
       <para>
          Notice also that only one annotated parameter can be mandatory: <literal>@Thrown</literal>. This will be
@@ -265,7 +265,7 @@
                   <entry>No</entry>
                </row>
                <row>
-                  <entry>Joinpoint info</entry>
+                  <entry>JoinpointBean interface type</entry>
                   <entry>No</entry>
                   <entry>Yes</entry>
                   <entry>No</entry>

Modified: projects/aop/trunk/aop/docs/reference/reference/en/modules/pointcuts.xml
===================================================================
--- projects/aop/trunk/aop/docs/reference/reference/en/modules/pointcuts.xml	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/docs/reference/reference/en/modules/pointcuts.xml	2007-06-12 02:30:52 UTC (rev 63463)
@@ -468,12 +468,12 @@
          </para>
          <para>
             The other group of beans contains only information regarding the joinpoint itself, and are called the <literal>
-            JoinPointInfo</literal> group. All beans of this group are defined in interfaces, with <literal>
-            org.jboss.joinpoint.IJoinPointInfo</literal> being their common superinterface.
+            JoinPointBean</literal> group. All beans of this group are defined in interfaces, with <literal>
+            org.jboss.joinpoint.JoinPointBean</literal> being their common superinterface.
          </para>
          <para>
             The <literal>Invocation</literal> objects are available only to around advices. All other types of advices can use the
-            <literal>JoinPointInfo Beans</literal> to access joinpoint specific data.
+            <literal>JoinPointBean</literal> types to access joinpoint specific data.
          </para>
          <para>
             In both groups there is a specific type for each joinpoint type. The type of bean corresponding to each joinpoint type can be seen
@@ -536,7 +536,7 @@
                   </row>
                   <row>
                      <entry>Invocation</entry>
-                     <entry>IJoinpointInfo</entry>
+                     <entry>JoinpointBean</entry>
                      <entry>Target</entry>
                      <entry>Caller</entry>
                      <entry>Arguments</entry>
@@ -548,7 +548,7 @@
                      <entry>field read</entry>
                      <entry><literal>read</literal>, <literal>field</literal>, <literal>all</literal></entry>
                      <entry><literal>FieldReadInvocation</literal></entry>
-                     <entry><literal>IFieldInfo</literal></entry>
+                     <entry><literal>FieldAccess</literal></entry>
                      <entry>Yes</entry>
                      <entry>No</entry>
                      <entry>No</entry>
@@ -558,7 +558,7 @@
                      <entry>field write</entry>
                      <entry><literal>write</literal>, <literal>field</literal>, <literal>all</literal></entry>
                      <entry><literal>FieldWriteInvocation</literal></entry>
-                     <entry><literal>IFieldInfo</literal></entry>
+                     <entry><literal>FieldAccess</literal></entry>
                      <entry>Yes</entry>
                      <entry>No</entry>
                      <entry>Yes</entry>
@@ -568,7 +568,7 @@
                      <entry>method execution</entry>
                      <entry><literal>execution</literal>, <literal>all</literal></entry>
                      <entry><literal>MethodInvocation</literal></entry>
-                     <entry><literal>IMethodInfo</literal></entry>
+                     <entry><literal>MethodExecution</literal></entry>
                      <entry>Yes</entry>
                      <entry>No</entry>
                      <entry>Yes</entry>
@@ -578,7 +578,7 @@
                      <entry>constructor execution</entry>
                      <entry><literal>execution</literal></entry>
                      <entry><literal>ConstructorInvocation</literal></entry>
-                     <entry><literal>IConstructorInfo</literal></entry>
+                     <entry><literal>ConstructorExecution</literal></entry>
                      <entry>No</entry>
                      <entry>No</entry>
                      <entry>Yes</entry>
@@ -588,7 +588,7 @@
                      <entry>construction</entry>
                      <entry><literal>construction</literal></entry>
                      <entry><literal>ConstructionInvocation</literal></entry>
-                     <entry><literal>IConstructorInfo</literal></entry>
+                     <entry><literal>ConstructorExecution</literal></entry>
                      <entry>Yes</entry>
                      <entry>No</entry>
                      <entry>Yes</entry>
@@ -597,8 +597,8 @@
                   <row>
                      <entry>method call</entry>
                      <entry><literal>call</literal>, <literal>within</literal>, <literal>withincode</literal></entry>
-                     <entry><literal>MethodCalledByConstructorInvocation</literal>, <literal>MethodCalledByMethodInvocation</literal></entry>
-                     <entry><literal>IMethodByConInfo</literal>, <literal>IMethodByMethodInfo</literal></entry>
+                     <entry><literal>CallerInvocation</literal>, <literal>MethodCalledByConstructorInvocation</literal>, <literal>MethodCalledByMethodInvocation</literal></entry>
+                     <entry><literal>MethodCall</literal>, <literal>MethodCallByConstructor</literal>, <literal>MethodCallByMethod</literal></entry>
                      <entry>Yes</entry>
                      <entry>Yes</entry>
                      <entry>Yes</entry>
@@ -607,8 +607,8 @@
                   <row>
                      <entry>constructor call</entry>
                      <entry><literal>call</literal>, <literal>within</literal>, <literal>withincode</literal></entry>
-                     <entry><literal>ConstructorCalledByConstructorInvocation</literal>, <literal>ConstructorCalledByMethodInvocation</literal></entry>
-                     <entry><literal>IConByConInfo</literal>, <literal>IConByMethodInfo</literal></entry>
+                     <entry><literal>CallerInvocation</literal>, <literal>ConstructorCalledByConstructorInvocation</literal>, <literal>ConstructorCalledByMethodInvocation</literal></entry>
+                     <entry><literal>ConstructorCall</literal>, <literal>ConstructorCallByConstructor</literal>, <literal>ConstructorCallByMethod</literal></entry>
                      <entry>Yes</entry>
                      <entry>Yes</entry>
                      <entry>Yes</entry>
@@ -619,7 +619,7 @@
             The first column shows the joinpoint type. The second column shows which pointcut constructs can identify a joinpoint of that type.
             <literal>has</literal> and <literal>hasfield</literal> are additional constructs, and therefore are not shown in this table. The
             third column shows the specific type of joinpoint bean class that is used to represent that joinpoint. This column is split into two:
-            one for the <literal>Invocation</literal> beans, the other one for the <literal>JoinPointInfo</literal> ones. The fourth column is
+            one for the <literal>Invocation</literal> beans, the other one for the <literal>JoinPointBean</literal> ones. The fourth column is
             composed of four subcolumns, and it shows the context values avaialble for each joinpoint type. Notice that, on some of these values,
             there are additional restrictions for their availability. Like, for example, there is no target on a static method execution.
          </table>

Modified: projects/aop/trunk/aop/src/main/org/jboss/aop/advice/AdviceMethodProperties.java
===================================================================
--- projects/aop/trunk/aop/src/main/org/jboss/aop/advice/AdviceMethodProperties.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/main/org/jboss/aop/advice/AdviceMethodProperties.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -50,7 +50,7 @@
    //find properties
    private Class aspectClass;
    private String adviceName;
-   private Class infoType;
+   private Class joinPointBeanType;
    private Class invocationType;
    private Class target;
    private Class caller;
@@ -68,7 +68,7 @@
    public AdviceMethodProperties(
          Class aspectClass, 
          String adviceName, 
-         Class infoType,
+         Class joinPointBeanType,
          Class invocationType,
          Class joinpointReturnType,
          Class[] joinpointParameters,
@@ -78,7 +78,7 @@
    {
       this.aspectClass = aspectClass;
       this.adviceName = adviceName;
-      this.infoType = infoType;
+      this.joinPointBeanType = joinPointBeanType;
       this.invocationType = invocationType;
       this.joinpointReturnType = joinpointReturnType;
       this.joinpointParameters = joinpointParameters;
@@ -91,7 +91,7 @@
    public AdviceMethodProperties(
          Class aspectClass,
          String adviceName,
-         Class infoType,
+         Class joinPointBeanType,
          Class invocationType,
          Class joinpointReturnType,
          Class[] joinpointParameters,
@@ -101,7 +101,7 @@
          Class caller,
          boolean callerAvailable)
    {
-      this (aspectClass, adviceName, infoType, invocationType, joinpointReturnType,
+      this (aspectClass, adviceName, joinPointBeanType, invocationType, joinpointReturnType,
       joinpointParameters, joinpointExceptions, target, targetAvailable);
       this.caller = caller;
       this.callerAvailable = callerAvailable;
@@ -126,9 +126,9 @@
    }
 
 
-   public Class getInfoType()
+   public Class getJoinPointBeanType()
    {
-      return infoType;
+      return joinPointBeanType;
    }
 
 

Modified: projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java
===================================================================
--- projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -1,9 +1,9 @@
 package org.jboss.aop.advice.annotation;
 
-import org.jboss.aop.JoinPointInfo;
 import org.jboss.aop.advice.AdviceMethodProperties;
 import org.jboss.aop.joinpoint.FieldReadInvocation;
 import org.jboss.aop.joinpoint.Invocation;
+import org.jboss.aop.joinpoint.JoinPointBean;
 
 /**
  * Represents the set of rules associated with a parameter annotation. Every parameter
@@ -17,12 +17,12 @@
     * Rule for parameter annotation {@link JoinPoint}.
     */
    JOIN_POINT (
-         JoinPoint.class, JoinPointInfo.class, AdviceMethodProperties.JOINPOINT_ARG,
+         JoinPoint.class, JoinPointBean.class, AdviceMethodProperties.JOINPOINT_ARG,
          700, false, true)
    {
       public Object getAssignableFrom(AdviceMethodProperties properties)
       {
-         return properties.getInfoType();
+         return properties.getJoinPointBeanType();
       }
    },
    

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointAspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointAspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -117,7 +117,7 @@
       afterJoinPoint = joinPoint;
    }
    
-   public void after2(@JoinPoint ConstructorExecution constructorInfo)
+   public void after2(@JoinPoint ConstructorExecution constructorExecution)
    {
       Assert.fail("This advice should never be executed");
    }

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointTestCase.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointTestCase.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/JoinPointTestCase.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -109,9 +109,9 @@
       assertNull(JoinPointAspect.finallyJoinPoint);
       
       assertTrue(JoinPointAspect.afterJoinPoint instanceof FieldAccess);
-      FieldAccess fieldInfo = (FieldAccess) JoinPointAspect.afterJoinPoint;
-      assertEquals("number", fieldInfo.getAdvisedField().getName());
-      assertFalse(fieldInfo.isRead());
+      FieldAccess fieldAccess = (FieldAccess) JoinPointAspect.afterJoinPoint;
+      assertEquals("number", fieldAccess.getAdvisedField().getName());
+      assertFalse(fieldAccess.isRead());
    }
    
    public void testFieldWrite2()
@@ -129,9 +129,9 @@
       assertSame(JoinPointAspect.beforeJoinPoint,
             JoinPointAspect.finallyJoinPoint);
       assertTrue(JoinPointAspect.beforeJoinPoint instanceof FieldAccess);
-      FieldAccess fieldInfo = (FieldAccess) JoinPointAspect.beforeJoinPoint;
-      assertEquals("text", fieldInfo.getAdvisedField().getName());
-      assertFalse(fieldInfo.isRead());
+      FieldAccess fieldAccess = (FieldAccess) JoinPointAspect.beforeJoinPoint;
+      assertEquals("text", fieldAccess.getAdvisedField().getName());
+      assertFalse(fieldAccess.isRead());
    }
    
    public void testFieldWrite3()
@@ -147,9 +147,9 @@
       assertNull(JoinPointAspect.finallyJoinPoint);
       
       assertTrue(JoinPointAspect.afterJoinPoint instanceof FieldAccess);
-      FieldAccess fieldInfo = (FieldAccess) JoinPointAspect.afterJoinPoint;
-      assertEquals("text", fieldInfo.getAdvisedField().getName());
-      assertTrue(fieldInfo.isRead());
+      FieldAccess fieldAccess = (FieldAccess) JoinPointAspect.afterJoinPoint;
+      assertEquals("text", fieldAccess.getAdvisedField().getName());
+      assertTrue(fieldAccess.isRead());
    }
    
    public void testMethodExecution1() throws Exception

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedBeforeAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedBeforeAspect.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedBeforeAspect.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -155,7 +155,7 @@
       before1 = "";
    }
    
-   public void before1(@JoinPoint MethodExecution constructorInfo)
+   public void before1(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -237,7 +237,7 @@
       before2 = "";
    }
    
-   public void before2(@JoinPoint MethodExecution constructorInfo)
+   public void before2(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -314,7 +314,7 @@
       before3 = "";
    }
    
-   public void before3(@JoinPoint MethodExecution constructorInfo)
+   public void before3(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -386,7 +386,7 @@
       before4 = "";
    }
    
-   public void before4(@JoinPoint MethodExecution constructorInfo)
+   public void before4(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -453,7 +453,7 @@
       before5 = "";
    }
    
-   public void before5(@JoinPoint MethodExecution constructorInfo)
+   public void before5(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -515,7 +515,7 @@
       before6 = "";
    }
    
-   public void before6(@JoinPoint MethodExecution constructorInfo)
+   public void before6(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -572,7 +572,7 @@
       before7 = "";
    }
    
-   public void before7(@JoinPoint MethodExecution constructorInfo)
+   public void before7(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -624,7 +624,7 @@
       before8 = "";
    }
    
-   public void before8(@JoinPoint MethodExecution constructorInfo)
+   public void before8(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -671,7 +671,7 @@
       before9 = "";
    }
    
-   public void before9(@JoinPoint MethodExecution constructorInfo)
+   public void before9(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -713,7 +713,7 @@
       before10 = "";
    }
    
-   public void before10(@JoinPoint MethodExecution constructorInfo)
+   public void before10(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -750,7 +750,7 @@
       before11 = "";
    }
    
-   public void before11(@JoinPoint MethodExecution constructorInfo)
+   public void before11(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -782,7 +782,7 @@
       before12 = "";
    }
    
-   public void before12(@JoinPoint MethodExecution constructorInfo)
+   public void before12(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -814,7 +814,7 @@
       before13 = "";
    }
    
-   public void before13(@JoinPoint MethodExecution constructorInfo)
+   public void before13(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -841,7 +841,7 @@
       before14 = "";
    }
    
-   public void before14(@JoinPoint MethodExecution constructorInfo)
+   public void before14(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -863,7 +863,7 @@
       before15 = "";
    }
    
-   public void before15(@JoinPoint MethodExecution constructorInfo)
+   public void before15(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -880,7 +880,7 @@
       before16 = "";
    }
    
-   public void before16(@JoinPoint MethodExecution constructorInfo)
+   public void before16(@JoinPoint MethodExecution methodExecution)
    {
       Assert.fail("This advice should never be executed");
    }
@@ -892,12 +892,12 @@
    
    /* BEFORE17 ADVICE */
    
-   public void before17(@JoinPoint FieldAccess fieldInfo, @Arg String text)
+   public void before17(@JoinPoint FieldAccess fieldAccess, @Arg String text)
    {
       before17 = "FieldAccess,String";
    }
    
-   public void before17(@JoinPoint FieldAccess fieldInfo)
+   public void before17(@JoinPoint FieldAccess fieldAccess)
    {
       before17 = "FieldAccess";
    }

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/container/ContainerTestCase.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/container/ContainerTestCase.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/container/ContainerTestCase.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -23,6 +23,10 @@
 
 import java.lang.reflect.Method;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import junit.textui.TestRunner;
+
 import org.jboss.aop.AspectManager;
 import org.jboss.aop.ClassContainer;
 import org.jboss.aop.MethodInfo;
@@ -31,10 +35,6 @@
 import org.jboss.aop.util.MethodHashing;
 import org.jboss.test.aop.AOPTestWithSetup;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-import junit.textui.TestRunner;
-
 /**
 *
 * @author <a href="mailto:kabir.khan at jboss.org">Kabir Khan</a>




More information about the jboss-cvs-commits mailing list
--- projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java	2007-06-11 22:22:36 UTC (rev 63462)
+++ projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java	2007-06-12 02:30:52 UTC (rev 63463)
@@ -26,13 +26,13 @@
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
-import org.jboss.aop.JoinPointInfo;
 import org.jboss.aop.joinpoint.Invocation;
+import org.jboss.aop.joinpoint.JoinPointBean;
 
 /**
  * Use this annotation on the advice parameter that receives:
  * <ul>
  * <li>{@link JoinPointInfo} or one of its subtypes (for before, after and throwing
  * advices);</li>
  * <li>{@link Invocation} or one of its subtypes (for around
  * advices).</li>
@@ -26,13 +26,13 @@
  * Use this annotation on the advice parameter that receives:
  * <ul>
- * <li>{@link JoinPointInfo} or one of its subtypes (for before, after and throwing
+ * <li>{@link JoinPointBean} or one of its subtypes (for before, after and throwing
  * advices);</li>
  * <li>{@link Invocation} or one of its subtypes (for around

Modified: projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java
===================================================================